@@ -34,15 +34,31 @@
 #include <string.h>
 #include <gtk/gtk.h>
 
-#define NM_VPN_API_SUBJECT_TO_CHANGE
+#ifdef NM_OPENVPN_OLD
 
+#define NM_VPN_LIBNM_COMPAT
 #include <nm-vpn-plugin-ui-interface.h>
 #include <nm-setting-vpn.h>
 #include <nm-setting-connection.h>
 #include <nm-setting-ip4-config.h>
 #include <nm-ui-utils.h>
 
-#include "src/nm-fortisslvpn-service.h"
+#define FORTISSLVPN_EDITOR_PLUGIN_ERROR                     NM_SETTING_VPN_ERROR
+#define FORTISSLVPN_EDITOR_PLUGIN_ERROR_INVALID_PROPERTY    NM_SETTING_VPN_ERROR_INVALID_PROPERTY
+
+#define nm_simple_connection_new nm_connection_new
+
+#else /* !NM_OPENVPN_OLD */
+
+#include <NetworkManager.h>
+#include <nma-ui-utils.h>
+
+#define FORTISSLVPN_EDITOR_PLUGIN_ERROR                     NM_CONNECTION_ERROR
+#define FORTISSLVPN_EDITOR_PLUGIN_ERROR_INVALID_PROPERTY    NM_CONNECTION_ERROR_INVALID_PROPERTY
+
+#endif
+
+#include "src/nm-fortisslvpn-service-defines.h"
 #include "nm-fortisslvpn.h"
 
 #define FORTISSLVPN_PLUGIN_NAME    _("Fortinet SSLVPN")
@@ -53,21 +69,28 @@ typedef void (*ChangedCallback) (GtkWidget *widget, gpointer user_data);
 
 /************** plugin class **************/
 
-static void fortisslvpn_plugin_ui_interface_init (NMVpnPluginUiInterface *iface_class);
+enum {
+	PROP_0,
+	PROP_NAME,
+	PROP_DESC,
+	PROP_SERVICE
+};
 
-G_DEFINE_TYPE_EXTENDED (FortisslvpnPluginUi, fortisslvpn_plugin_ui, G_TYPE_OBJECT, 0,
-                        G_IMPLEMENT_INTERFACE (NM_TYPE_VPN_PLUGIN_UI_INTERFACE,
-                                               fortisslvpn_plugin_ui_interface_init))
+static void fortisslvpn_editor_plugin_interface_init (NMVpnEditorPluginInterface *iface_class);
+
+G_DEFINE_TYPE_EXTENDED (FortisslvpnEditorPlugin, fortisslvpn_editor_plugin, G_TYPE_OBJECT, 0,
+                        G_IMPLEMENT_INTERFACE (NM_TYPE_VPN_EDITOR_PLUGIN,
+                                               fortisslvpn_editor_plugin_interface_init))
 
 /************** UI widget class **************/
 
-static void fortisslvpn_plugin_ui_widget_interface_init (NMVpnPluginUiWidgetInterface *iface_class);
+static void fortisslvpn_editor_interface_init (NMVpnEditorInterface *iface_class);
 
-G_DEFINE_TYPE_EXTENDED (FortisslvpnPluginUiWidget, fortisslvpn_plugin_ui_widget, G_TYPE_OBJECT, 0,
-                        G_IMPLEMENT_INTERFACE (NM_TYPE_VPN_PLUGIN_UI_WIDGET_INTERFACE,
-                                               fortisslvpn_plugin_ui_widget_interface_init))
+G_DEFINE_TYPE_EXTENDED (FortisslvpnEditor, fortisslvpn_editor, G_TYPE_OBJECT, 0,
+                        G_IMPLEMENT_INTERFACE (NM_TYPE_VPN_EDITOR,
+                                               fortisslvpn_editor_interface_init))
 
-#define FORTISSLVPN_PLUGIN_UI_WIDGET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), FORTISSLVPN_TYPE_PLUGIN_UI_WIDGET, FortisslvpnPluginUiWidgetPrivate))
+#define FORTISSLVPN_EDITOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), FORTISSLVPN_TYPE_EDITOR, FortisslvpnEditorPrivate))
 
 typedef struct {
 	GtkBuilder *builder;
@@ -77,45 +100,12 @@ typedef struct {
 	gboolean window_added;
 	gboolean new_connection;
 	gchar *trusted_cert;
-} FortisslvpnPluginUiWidgetPrivate;
-
-
-GQuark
-fortisslvpn_plugin_ui_error_quark (void)
-{
-	static GQuark error_quark = 0;
-
-	if (G_UNLIKELY (error_quark == 0))
-		error_quark = g_quark_from_static_string ("fortisslvpn-plugin-ui-error-quark");
-
-	return error_quark;
-}
-
-/* This should really be standard. */
-#define ENUM_ENTRY(NAME, DESC) { NAME, "" #NAME "", DESC }
-
-GType
-fortisslvpn_plugin_ui_error_get_type (void)
-{
-	static GType etype = 0;
-
-	if (etype == 0) {
-		static const GEnumValue values[] = {
-			/* Unknown error. */
-			ENUM_ENTRY (FORTISSLVPN_PLUGIN_UI_ERROR_UNKNOWN, "UnknownError"),
-			/* The specified property was invalid. */
-			ENUM_ENTRY (FORTISSLVPN_PLUGIN_UI_ERROR_INVALID_PROPERTY, "InvalidProperty"),
-			{ 0, 0, 0 }
-		};
-		etype = g_enum_register_static ("FortisslvpnPluginUiError", values);
-	}
-	return etype;
-}
+} FortisslvpnEditorPrivate;
 
 static gboolean
-check_validity (FortisslvpnPluginUiWidget *self, GError **error)
+check_validity (FortisslvpnEditor *self, GError **error)
 {
-	FortisslvpnPluginUiWidgetPrivate *priv = FORTISSLVPN_PLUGIN_UI_WIDGET_GET_PRIVATE (self);
+	FortisslvpnEditorPrivate *priv = FORTISSLVPN_EDITOR_GET_PRIVATE (self);
 	GtkWidget *widget;
 	const char *str;
 
@@ -123,8 +113,8 @@ check_validity (FortisslvpnPluginUiWidget *self, GError **error)
 	str = gtk_entry_get_text (GTK_ENTRY (widget));
 	if (!str || !strlen (str)) {
 		g_set_error (error,
-		             FORTISSLVPN_PLUGIN_UI_ERROR,
-		             FORTISSLVPN_PLUGIN_UI_ERROR_INVALID_PROPERTY,
+		             FORTISSLVPN_EDITOR_PLUGIN_ERROR,
+		             FORTISSLVPN_EDITOR_PLUGIN_ERROR_INVALID_PROPERTY,
 		             NM_FORTISSLVPN_KEY_GATEWAY);
 		return FALSE;
 	}
@@ -135,17 +125,17 @@ check_validity (FortisslvpnPluginUiWidget *self, GError **error)
 static void
 stuff_changed_cb (GtkWidget *widget, gpointer user_data)
 {
-	g_signal_emit_by_name (FORTISSLVPN_PLUGIN_UI_WIDGET (user_data), "changed");
+	g_signal_emit_by_name (FORTISSLVPN_EDITOR (user_data), "changed");
 }
 
 static void
-setup_password_widget (FortisslvpnPluginUiWidget *self,
+setup_password_widget (FortisslvpnEditor *self,
                        const char *entry_name,
-                       NMSettingVPN *s_vpn,
+                       NMSettingVpn *s_vpn,
                        const char *secret_name,
                        gboolean new_connection)
 {
-	FortisslvpnPluginUiWidgetPrivate *priv = FORTISSLVPN_PLUGIN_UI_WIDGET_GET_PRIVATE (self);
+	FortisslvpnEditorPrivate *priv = FORTISSLVPN_EDITOR_GET_PRIVATE (self);
 	GtkWidget *widget;
 	const char *value;
 
@@ -162,9 +152,9 @@ setup_password_widget (FortisslvpnPluginUiWidget *self,
 }
 
 static void
-show_toggled_cb (GtkCheckButton *button, FortisslvpnPluginUiWidget *self)
+show_toggled_cb (GtkCheckButton *button, FortisslvpnEditor *self)
 {
-	FortisslvpnPluginUiWidgetPrivate *priv = FORTISSLVPN_PLUGIN_UI_WIDGET_GET_PRIVATE (self);
+	FortisslvpnEditorPrivate *priv = FORTISSLVPN_EDITOR_GET_PRIVATE (self);
 	GtkWidget *widget;
 	gboolean visible;
 
@@ -180,18 +170,18 @@ password_storage_changed_cb (GObject *entry,
                              GParamSpec *pspec,
                              gpointer user_data)
 {
-	FortisslvpnPluginUiWidget *self = FORTISSLVPN_PLUGIN_UI_WIDGET (user_data);
+	FortisslvpnEditor *self = FORTISSLVPN_EDITOR (user_data);
 
 	stuff_changed_cb (NULL, self);
 }
 
 static void
-init_password_icon (FortisslvpnPluginUiWidget *self,
-                    NMSettingVPN *s_vpn,
+init_password_icon (FortisslvpnEditor *self,
+                    NMSettingVpn *s_vpn,
                     const char *secret_key,
                     const char *entry_name)
 {
-	FortisslvpnPluginUiWidgetPrivate *priv = FORTISSLVPN_PLUGIN_UI_WIDGET_GET_PRIVATE (self);
+	FortisslvpnEditorPrivate *priv = FORTISSLVPN_EDITOR_GET_PRIVATE (self);
 	GtkWidget *entry;
 	const char *value = NULL;
 	NMSettingSecretFlags pw_flags = NM_SETTING_SECRET_FLAG_NONE;
@@ -229,8 +219,8 @@ advanced_dialog_delete_cb (GtkWidget *dialog, gpointer user_data)
 static void
 advanced_dialog_response_cb (GtkWidget *dialog, gint response, gpointer user_data)
 {
-	FortisslvpnPluginUiWidget *self = FORTISSLVPN_PLUGIN_UI_WIDGET (user_data);
-	FortisslvpnPluginUiWidgetPrivate *priv = FORTISSLVPN_PLUGIN_UI_WIDGET_GET_PRIVATE (self);
+	FortisslvpnEditor *self = FORTISSLVPN_EDITOR (user_data);
+	FortisslvpnEditorPrivate *priv = FORTISSLVPN_EDITOR_GET_PRIVATE (self);
 	GtkEntry *entry = GTK_ENTRY (gtk_builder_get_object (priv->builder, "trusted_cert_entry"));
 
 	g_assert (entry);
@@ -248,8 +238,8 @@ advanced_dialog_response_cb (GtkWidget *dialog, gint response, gpointer user_dat
 static void
 advanced_button_clicked_cb (GtkWidget *button, gpointer user_data)
 {
-	FortisslvpnPluginUiWidget *self = FORTISSLVPN_PLUGIN_UI_WIDGET (user_data);
-	FortisslvpnPluginUiWidgetPrivate *priv = FORTISSLVPN_PLUGIN_UI_WIDGET_GET_PRIVATE (self);
+	FortisslvpnEditor *self = FORTISSLVPN_EDITOR (user_data);
+	FortisslvpnEditorPrivate *priv = FORTISSLVPN_EDITOR_GET_PRIVATE (self);
 	GtkWidget *dialog = GTK_WIDGET (gtk_builder_get_object (priv->builder, "advanced_dialog"));
 	g_assert (dialog);
 
@@ -268,14 +258,14 @@ advanced_button_clicked_cb (GtkWidget *button, gpointer user_data)
 }
 
 static gboolean
-init_plugin_ui (FortisslvpnPluginUiWidget *self, NMConnection *connection, GError **error)
+init_editor_plugin (FortisslvpnEditor *self, NMConnection *connection, GError **error)
 {
-	FortisslvpnPluginUiWidgetPrivate *priv = FORTISSLVPN_PLUGIN_UI_WIDGET_GET_PRIVATE (self);
-	NMSettingVPN *s_vpn;
+	FortisslvpnEditorPrivate *priv = FORTISSLVPN_EDITOR_GET_PRIVATE (self);
+	NMSettingVpn *s_vpn;
 	GtkWidget *widget;
 	const char *value;
 
-	s_vpn = (NMSettingVPN *) nm_connection_get_setting (connection, NM_TYPE_SETTING_VPN);
+	s_vpn = (NMSettingVpn *) nm_connection_get_setting (connection, NM_TYPE_SETTING_VPN);
 
 	priv->group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
@@ -380,16 +370,16 @@ init_plugin_ui (FortisslvpnPluginUiWidget *self, NMConnection *connection, GErro
 }
 
 static GObject *
-get_widget (NMVpnPluginUiWidgetInterface *iface)
+get_widget (NMVpnEditor *iface)
 {
-	FortisslvpnPluginUiWidget *self = FORTISSLVPN_PLUGIN_UI_WIDGET (iface);
-	FortisslvpnPluginUiWidgetPrivate *priv = FORTISSLVPN_PLUGIN_UI_WIDGET_GET_PRIVATE (self);
+	FortisslvpnEditor *self = FORTISSLVPN_EDITOR (iface);
+	FortisslvpnEditorPrivate *priv = FORTISSLVPN_EDITOR_GET_PRIVATE (self);
 
 	return G_OBJECT (priv->widget);
 }
 
 static void
-save_password_and_flags (NMSettingVPN *s_vpn,
+save_password_and_flags (NMSettingVpn *s_vpn,
                          GtkBuilder *builder,
                          const char *entry_name,
                          const char *secret_key)
@@ -419,13 +409,13 @@ save_password_and_flags (NMSettingVPN *s_vpn,
 }
 
 static gboolean
-update_connection (NMVpnPluginUiWidgetInterface *iface,
+update_connection (NMVpnEditor *iface,
                    NMConnection *connection,
                    GError **error)
 {
-	FortisslvpnPluginUiWidget *self = FORTISSLVPN_PLUGIN_UI_WIDGET (iface);
-	FortisslvpnPluginUiWidgetPrivate *priv = FORTISSLVPN_PLUGIN_UI_WIDGET_GET_PRIVATE (self);
-	NMSettingVPN *s_vpn;
+	FortisslvpnEditor *self = FORTISSLVPN_EDITOR (iface);
+	FortisslvpnEditorPrivate *priv = FORTISSLVPN_EDITOR_GET_PRIVATE (self);
+	NMSettingVpn *s_vpn;
 	GtkWidget *widget;
 	const char *str;
 	gboolean valid = FALSE;
@@ -493,25 +483,25 @@ is_new_func (const char *key, const char *value, gpointer user_data)
 	*is_new = FALSE;
 }
 
-static NMVpnPluginUiWidgetInterface *
-nm_vpn_plugin_ui_widget_interface_new (NMConnection *connection, GError **error)
+static NMVpnEditor *
+nm_vpn_editor_interface_new (NMConnection *connection, GError **error)
 {
-	NMVpnPluginUiWidgetInterface *object;
-	FortisslvpnPluginUiWidgetPrivate *priv;
+	NMVpnEditor *object;
+	FortisslvpnEditorPrivate *priv;
 	char *ui_file;
 	gboolean new = TRUE;
-	NMSettingVPN *s_vpn;
+	NMSettingVpn *s_vpn;
 
 	if (error)
 		g_return_val_if_fail (*error == NULL, NULL);
 
-	object = NM_VPN_PLUGIN_UI_WIDGET_INTERFACE (g_object_new (FORTISSLVPN_TYPE_PLUGIN_UI_WIDGET, NULL));
+	object = g_object_new (FORTISSLVPN_TYPE_EDITOR, NULL);
 	if (!object) {
-		g_set_error (error, FORTISSLVPN_PLUGIN_UI_ERROR, 0, "could not create fortisslvpn object");
+		g_set_error (error, FORTISSLVPN_EDITOR_PLUGIN_ERROR, 0, "could not create fortisslvpn object");
 		return NULL;
 	}
 
-	priv = FORTISSLVPN_PLUGIN_UI_WIDGET_GET_PRIVATE (object);
+	priv = FORTISSLVPN_EDITOR_GET_PRIVATE (object);
 
 	ui_file = g_strdup_printf ("%s/%s", UIDIR, "nm-fortisslvpn-dialog.ui");
 	priv->builder = gtk_builder_new ();
@@ -522,7 +512,7 @@ nm_vpn_plugin_ui_widget_interface_new (NMConnection *connection, GError **error)
 		g_warning ("Couldn't load builder file: %s",
 		           error && *error ? (*error)->message : "(unknown)");
 		g_clear_error (error);
-		g_set_error (error, FORTISSLVPN_PLUGIN_UI_ERROR, 0,
+		g_set_error (error, FORTISSLVPN_EDITOR_PLUGIN_ERROR, 0,
 		             "could not load required resources at %s", ui_file);
 		g_free (ui_file);
 		g_object_unref (object);
@@ -532,7 +522,7 @@ nm_vpn_plugin_ui_widget_interface_new (NMConnection *connection, GError **error)
 
 	priv->widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "fortisslvpn-vbox"));
 	if (!priv->widget) {
-		g_set_error (error, FORTISSLVPN_PLUGIN_UI_ERROR, 0, "could not load UI widget");
+		g_set_error (error, FORTISSLVPN_EDITOR_PLUGIN_ERROR, 0, "could not load UI widget");
 		g_object_unref (object);
 		return NULL;
 	}
@@ -545,7 +535,7 @@ nm_vpn_plugin_ui_widget_interface_new (NMConnection *connection, GError **error)
 		nm_setting_vpn_foreach_data_item (s_vpn, is_new_func, &new);
 	priv->new_connection = new;
 
-	if (!init_plugin_ui (FORTISSLVPN_PLUGIN_UI_WIDGET (object), connection, error)) {
+	if (!init_editor_plugin (FORTISSLVPN_EDITOR (object), connection, error)) {
 		g_object_unref (object);
 		return NULL;
 	}
@@ -556,8 +546,8 @@ nm_vpn_plugin_ui_widget_interface_new (NMConnection *connection, GError **error)
 static void
 dispose (GObject *object)
 {
-	FortisslvpnPluginUiWidget *plugin = FORTISSLVPN_PLUGIN_UI_WIDGET (object);
-	FortisslvpnPluginUiWidgetPrivate *priv = FORTISSLVPN_PLUGIN_UI_WIDGET_GET_PRIVATE (plugin);
+	FortisslvpnEditor *plugin = FORTISSLVPN_EDITOR (object);
+	FortisslvpnEditorPrivate *priv = FORTISSLVPN_EDITOR_GET_PRIVATE (plugin);
 	GtkWidget *widget;
 
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "user_password_entry"));
@@ -577,26 +567,26 @@ dispose (GObject *object)
 	if (priv->builder)
 		g_object_unref (priv->builder);
 
-	G_OBJECT_CLASS (fortisslvpn_plugin_ui_widget_parent_class)->dispose (object);
+	G_OBJECT_CLASS (fortisslvpn_editor_parent_class)->dispose (object);
 }
 
 static void
-fortisslvpn_plugin_ui_widget_class_init (FortisslvpnPluginUiWidgetClass *req_class)
+fortisslvpn_editor_class_init (FortisslvpnEditorClass *req_class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (req_class);
 
-	g_type_class_add_private (req_class, sizeof (FortisslvpnPluginUiWidgetPrivate));
+	g_type_class_add_private (req_class, sizeof (FortisslvpnEditorPrivate));
 
 	object_class->dispose = dispose;
 }
 
 static void
-fortisslvpn_plugin_ui_widget_init (FortisslvpnPluginUiWidget *plugin)
+fortisslvpn_editor_init (FortisslvpnEditor *plugin)
 {
 }
 
 static void
-fortisslvpn_plugin_ui_widget_interface_init (NMVpnPluginUiWidgetInterface *iface_class)
+fortisslvpn_editor_interface_init (NMVpnEditorInterface *iface_class)
 {
 	/* interface implementation */
 	iface_class->get_widget = get_widget;
@@ -604,15 +594,15 @@ fortisslvpn_plugin_ui_widget_interface_init (NMVpnPluginUiWidgetInterface *iface
 }
 
 static guint32
-get_capabilities (NMVpnPluginUiInterface *iface)
+get_capabilities (NMVpnEditorPlugin *iface)
 {
-	return NM_VPN_PLUGIN_UI_CAPABILITY_NONE;
+	return NM_VPN_EDITOR_PLUGIN_CAPABILITY_NONE;
 }
 
-static NMVpnPluginUiWidgetInterface *
-ui_factory (NMVpnPluginUiInterface *iface, NMConnection *connection, GError **error)
+static NMVpnEditor *
+get_editor (NMVpnEditorPlugin *iface, NMConnection *connection, GError **error)
 {
-	return nm_vpn_plugin_ui_widget_interface_new (connection, error);
+	return nm_vpn_editor_interface_new (connection, error);
 }
 
 static void
@@ -620,13 +610,13 @@ get_property (GObject *object, guint prop_id,
 			  GValue *value, GParamSpec *pspec)
 {
 	switch (prop_id) {
-	case NM_VPN_PLUGIN_UI_INTERFACE_PROP_NAME:
+	case PROP_NAME:
 		g_value_set_string (value, FORTISSLVPN_PLUGIN_NAME);
 		break;
-	case NM_VPN_PLUGIN_UI_INTERFACE_PROP_DESC:
+	case PROP_DESC:
 		g_value_set_string (value, FORTISSLVPN_PLUGIN_DESC);
 		break;
-	case NM_VPN_PLUGIN_UI_INTERFACE_PROP_SERVICE:
+	case PROP_SERVICE:
 		g_value_set_string (value, FORTISSLVPN_PLUGIN_SERVICE);
 		break;
 	default:
@@ -636,44 +626,44 @@ get_property (GObject *object, guint prop_id,
 }
 
 static void
-fortisslvpn_plugin_ui_class_init (FortisslvpnPluginUiClass *req_class)
+fortisslvpn_editor_plugin_class_init (FortisslvpnEditorPluginClass *req_class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (req_class);
 
 	object_class->get_property = get_property;
 
 	g_object_class_override_property (object_class,
-	                                  NM_VPN_PLUGIN_UI_INTERFACE_PROP_NAME,
-	                                  NM_VPN_PLUGIN_UI_INTERFACE_NAME);
+	                                  PROP_NAME,
+	                                  NM_VPN_EDITOR_PLUGIN_NAME);
 
 	g_object_class_override_property (object_class,
-	                                  NM_VPN_PLUGIN_UI_INTERFACE_PROP_DESC,
-	                                  NM_VPN_PLUGIN_UI_INTERFACE_DESC);
+	                                  PROP_DESC,
+	                                  NM_VPN_EDITOR_PLUGIN_DESCRIPTION);
 
 	g_object_class_override_property (object_class,
-	                                  NM_VPN_PLUGIN_UI_INTERFACE_PROP_SERVICE,
-	                                  NM_VPN_PLUGIN_UI_INTERFACE_SERVICE);
+	                                  PROP_SERVICE,
+	                                  NM_VPN_EDITOR_PLUGIN_SERVICE);
 }
 
 static void
-fortisslvpn_plugin_ui_init (FortisslvpnPluginUi *plugin)
+fortisslvpn_editor_plugin_init (FortisslvpnEditorPlugin *plugin)
 {
 }
 
 static void
-fortisslvpn_plugin_ui_interface_init (NMVpnPluginUiInterface *iface_class)
+fortisslvpn_editor_plugin_interface_init (NMVpnEditorPluginInterface *iface_class)
 {
 	/* interface implementation */
-	iface_class->ui_factory = ui_factory;
+	iface_class->get_editor = get_editor;
 	iface_class->get_capabilities = get_capabilities;
 	iface_class->import_from_file = NULL;
 	iface_class->export_to_file = NULL;
-	iface_class->get_suggested_name = NULL;
+	iface_class->get_suggested_filename = NULL;
 }
 
 
-G_MODULE_EXPORT NMVpnPluginUiInterface *
-nm_vpn_plugin_ui_factory (GError **error)
+G_MODULE_EXPORT NMVpnEditorPlugin *
+nm_vpn_editor_plugin_factory (GError **error)
 {
 	if (error)
 		g_return_val_if_fail (*error == NULL, NULL);
@@ -681,6 +671,6 @@ nm_vpn_plugin_ui_factory (GError **error)
 	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
-	return NM_VPN_PLUGIN_UI_INTERFACE (g_object_new (FORTISSLVPN_TYPE_PLUGIN_UI, NULL));
+	return g_object_new (FORTISSLVPN_TYPE_EDITOR_PLUGIN, NULL);
 }
 
